@@ -9,13 +9,13 @@ require DynaLoader;
 use vars qw(@ISA %EXPORT_TAGS @EXPORT_OK $VERSION);
 @ISA = qw(Exporter DynaLoader);
 
-$VERSION = '0.31_19';
+$VERSION = '0.32_01';
 
 %EXPORT_TAGS = (
     'all' => [qw(
         &clear &compare &copy &generate &generate_random &generate_time
         &is_null &parse &time &type &unparse &unparse_lower
-        &unparse_upper &uuid &variant
+        &unparse_upper &uuid &uuid1 &uuid4 &variant
     )],
 );
 
@@ -36,7 +36,9 @@ UUID - Universally Unique Identifier library for Perl
 
     use UUID 'uuid';
 
-    $string = uuid();   # generate stringified UUID
+    $string = uuid();   # generate UUID string, prefer v4, fallback v1
+    $string = uuid1();  # generate UUID string, always v1
+    $string = uuid4();  # generate UUID string, always v4
 
     UUID::generate($uuid);               # new binary UUID; prefer random
     UUID::generate_random($uuid);        # new binary UUID; use random
@@ -74,7 +76,7 @@ Environment (DCE) utility uuidgen.
 
 All generated UUIDs are either type 1 from B<UUID::generate_time()>, or
 type 4 from B<UUID::generate_random()>. And all are variant 1, meaning
-compliant with current OSF DCE standard.
+compliant with the OSF DCE standard as described in RFC4122.
 
 =head1 FUNCTIONS
 
@@ -118,38 +120,45 @@ comparison returning similar values.
 
 =head2 B<generate(> I<$uuid> B<)>
 
-Generates a new binary UUID based on high quality randomness from
-I</dev/urandom>, if available.
+Generates a new version 4 binary UUID based on high quality randomness
+from I</dev/urandom> or I</dev/random>, if available.
 
-Alternately, the current time, the local ethernet MAC address (if
-available), and random data generated using a pseudo-random generator
-are used.
+If not, a new version 1 binary UUID is returned.
 
 The previous content of I<$uuid>, if any, is lost.
 
 =head2 B<generate_random(> I<$uuid> B<)>
 
-Generates a new binary UUID but forces the use of the all-random
-algorithm, even if a high-quality random number generator (i.e.,
-I</dev/urandom>) is not available, in which case a pseudo-random
-generator is used.
+Generates a new version 4 binary UUID even if a high-quality random
+number generator (e.g., I</dev/urandom>) is not available, in which case
+a pseudo-random generator is used.
 
 Note that the use of a pseudo-random generator may compromise the
 uniqueness of UUIDs generated in this fashion.
 
+If I</dev/urandom> and/or I</dev/random> are present, the system calls
+I<get_random()> and/or I<get_entropy()> are used first, if available.
+
+If the system calls are not available, randomness is read directly from
+the random devices, preferring I</dev/urandom> but falling back to
+I</dev/random> in non-blocking mode.
+
 =head2 B<generate_time(> I<$uuid> B<)>
 
-Generates a new binary UUID but forces the use of the alternative
-algorithm which uses the current time and the local ethernet MAC address
-(if available).
+Generates a new version 1 binary UUID which uses the current time and the
+local ethernet MAC address, if available.
 
-This algorithm used to be the default one used to generate UUIDs, but
-because of the use of the ethernet MAC address, it can leak information
-about when and where the UUID was generated.
+If the MAC address is not available, it is replaced randomly from best
+source with the multicast bit set to avoid conflict with addresses
+returned from network cards.
 
-This can cause privacy problems in some applications, so the B<generate()>
-function only uses this algorithm if a high-quality source of randomness
-is not available.
+This algorithm used to be the default used to generate UUIDs, but
+because of inclusion of the ethernet MAC address, it can leak
+information about where the UUID was generated.
+
+This can cause privacy problems in some applications, so the
+B<generate()> function only uses this algorithm if a high-quality source
+of randomness is not available.
 
 =head2 B<is_null(> I<$uuid> B<)>
 
@@ -180,17 +189,24 @@ Returns the type of binary I<$uuid>.
 This module only generates type 1 (time) and type 4 (random) UUIDs, but
 others may be found in the wild.
 
+Known types:
+    1  a.k.a. Version 1 - date/time and MAC address
+    2  a.k.a. Version 2 - date/time and MAC address, security version
+    3  a.k.a. Version 3 - namespace based, MD5 hash
+    4  a.k.a. Version 4 - random
+    5  a.k.a. Version 5 - namespace based, SHA-1 hash
+
 =head2 B<unparse(> I<$uuid>B<,> I<$string> B<)>
 
 Converts the binary UUID in I<$uuid> to string format and returns in
 I<$string>. The previous content of I<$string>, if any, is lost.
 
-The case of the hex digits returned may be upper or lower case, and is
-dependent on the system-dependent local default.
+Prior to version 0.32, casing of the return value was system-dependent.
+Later versions are lower case, per RFC4122.
 
 =head2 B<unparse_lower(> I<$uuid>B<,> I<$string> B<)>
 
-Same as B<unparse()> but I<$string> is forced to lower case.
+Same as B<unparse()>.
 
 =head2 B<unparse_upper(> I<$uuid>B<,> I<$string> B<)>
 
@@ -203,6 +219,14 @@ Creates a new string format UUID and returns it in a more Perlish way.
 Functionally the equivalent of calling B<generate()> and then B<unparse()>, but
 throwing away the intermediate binary UUID.
 
+=head2 B<uuid1()>
+
+Same as B<uuid()> but always version 1.
+
+=head2 B<uuid4()>
+
+Same as B<uuid()> but always version 4.
+
 =head2 B<variant(> I<$uuid> B<)>
 
 Returns the variant of binary I<$uuid>.
@@ -220,7 +244,7 @@ Known variants:
 =head1 UUID LIBRARY
 
 Prior to version 0.32, UUID required libuuid or similar be installed
-first. This is no longer the case. UUID now builds against a private
+first. This is no longer the case. UUID now builds against a bundled
 copy of the e2fsprogs UUID code.
 
 =head1 EXPORTS
@@ -228,13 +252,13 @@ copy of the e2fsprogs UUID code.
 None by default. All functions may be imported in the usual manner,
 either individually or all at once using the "I<:all>" tag.
 
-=head1 TODO
+=head1 THREAD SAFETY
 
-Need more tests and sanity checks.
+This module is believed to be thread safe.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014-2023 by Rick Myers.
+This software is Copyright (c) 2014-2024 by Rick Myers.
 
 This is free software, licensed under:
 
@@ -272,6 +296,8 @@ twata
 
 =head1 SEE ALSO
 
+RFC4122
+
 B<uuid(3)>, B<uuid_clear(3)>, B<uuid_compare(3)>, B<uuid_copy(3)>,
 B<uuid_generate(3)>, B<uuid_is_null(3)>, B<uuid_parse(3)>,
 B<uuid_unparse(3)>, B<perl(1)>.
