@@ -13,6 +13,7 @@ use Devel::CheckLib;
 my ($out, $flagfile) = @ARGV;
 my $conf  = [];
 my $flags = [];
+my $WIN32 = 0;  # native
 
 generate_conf($conf, $flags);
 write_conf   ($conf, $out);
@@ -67,7 +68,11 @@ sub generate_conf {
 
         # win32 native if on windows but not under some
         # sort of unix environ. i.e. native.
+        # sets $WIN32.
         try_win32_native   ($check, \$longest, $defines);
+
+        # requires $WIN32.
+        try_threads        ($check, \$longest, $defines);
     }
 #
 # these havent been handled yet. do they need to be?
@@ -77,8 +82,6 @@ sub generate_conf {
 #   SIZEOF_LONG_LONG
 #   SIZEOF_SHORT
 #
-#   TLS
-#
 }
 
 sub try_headers {
@@ -339,13 +342,83 @@ sub try_win32_native {
     ) {
         push @$defs, '#define USE_WIN32_NATIVE 1';
         print $msg, ' ..', '.'x$more, ' found';
+        $WIN32 = 1;
     }
     else {
         push @$defs, '#undef USE_WIN32_NATIVE';
         print $msg, ' ..', '.'x$more, ' missing';
+        $WIN32 = 0;
     }
 }
 
+sub try_threads {
+    my ($check, $long, $defs) = @_;
+    my $msg = join ' ', 'Checking thread storage';
+    my $len = length $msg;
+    if ($check) { $$long = $len if $len > $$long; return; }
+    my $more = $$long - $len;
+    # can we skip this if not -Dusethreads ?
+
+    open my $fh, '>', 'assertlibTHREADS.c' or die $!;
+    print $fh q{
+        int dec(void) {
+          static __thread int foo = 3;
+          return --foo;
+        }
+    };
+    close $fh;
+
+    open $fh, '>', 'assertlibDECLSPEC.c' or die $!;
+    print $fh q{
+        int dec(void) {
+          static __declspec(thread) int foo = 3;
+          return --foo;
+        }
+    };
+    close $fh;
+
+    my $Werror = $WIN32 ? '-WX'  : '-Werror';
+    my $lib    = $WIN32 ? 'ucrt' : 'c';
+
+    if ( check_lib(
+        header   => [qw(assertlibTHREADS.c)],
+        lib      => $lib, # always do at least this
+        ccflags  => "-I. $Werror",
+        debug    => 0,
+        function => q{
+            int rv;
+            rv = dec();
+            rv = dec();
+            rv = dec();
+            return rv;
+        },
+    )) {
+        push @$defs, '#define TLS __thread';
+        print $msg, ' ..', '.'x$more, ' __thread';
+    }
+    elsif ( check_lib(
+        header   => [qw(assertlibDECLSPEC.c)],
+        lib      => $lib, # always do at least this
+        ccflags  => "-I. $Werror",
+        debug    => 0,
+        function => q{
+            int rv;
+            rv = dec();
+            rv = dec();
+            rv = dec();
+            return rv;
+        },
+    )) {
+        push @$defs, '#define TLS __declspec(thread)';
+        print $msg, ' ..', '.'x$more, ' __declspec(thread)';
+    }
+    else {
+        push @$defs, '#undef TLS';
+        print $msg, ' ..', '.'x$more, ' none';
+    }
+    unlink qw(assertlibTHREADS.c assertlibDECLSPEC.c);
+}
+
 sub write_conf {
     my ($defines, $outfile) = @_;
 
