@@ -1,8 +1,10 @@
 #
 # Patch given file with DATA hunks and print to STDOUT.
 #
-# This patch fixes the incorrect assumption that Win32 is missing
-# sys/time.h in all cases.
+#
+# Patch to:
+#   * Fix incorrect assumption that Win32 is missing sys/time.h
+#     in all cases.
 #
 use strict;
 use warnings;
@@ -28,14 +30,18 @@ print $out;
 exit 0;
 
 __END__
---- a Fri Dec  1 23:41:31 2023
-+++ b Fri Dec  1 23:52:55 2023
-@@ -36,7 +36,7 @@
+--- ulib/uuid/uuid.h.new	Tue Jan  2 06:08:23 2024
++++ ulib/uuid/uuid.h	Tue Jan  2 14:48:25 2024
+@@ -35,8 +35,10 @@
+ #ifndef _UUID_UUID_H
  #define _UUID_UUID_H
  
++#include "config.h"
++
  #include <sys/types.h>
 -#ifndef _WIN32
-+#if ! defined(_WIN32) || defined(HAVE_SYS_TIME_H)
++#if ! defined(_WIN32) && defined(HAVE_SYS_TIME_H)
  #include <sys/time.h>
  #endif
  #include <time.h>
+
