@@ -24,9 +24,22 @@ unless ( file_name_is_absolute($file) ) {
     $file = rel2abs($file);
 }
 
-$file    = abs2rel($file);
-my $from = catfile( 'usrcP', $file );
-my $to   = catfile( 'ulib', $file );
+$file = abs2rel($file);
+
+# need a couple special cases
+my ($from, $to);
+if ($file eq 'uuid/uuid.h') {
+    $from = catfile( 'ulib', $file . '.new' );
+    $to   = catfile( 'ulib', $file );
+}
+elsif ($file eq 'config.h') {
+    $from = catfile( 'ulib', $file . '.new' );
+    $to   = catfile( 'ulib', $file );
+}
+else {
+    $from = catfile( 'usrcP', $file );
+    $to   = catfile( 'ulib', $file );
+}
 
 #print $from;
 #print $to;
